@@ -1,21 +1,51 @@
-from __future__ import absolute_import, print_function
+#-----------------------------------------------------------------------------
+# Copyright (c) 2012 - 2018, Anaconda, Inc. All rights reserved.
+#
+# Powered by the Bokeh Development Team.
+#
+# The full license is in the file LICENSE.txt, distributed with this software.
+#-----------------------------------------------------------------------------
 
+#-----------------------------------------------------------------------------
+# Boilerplate
+#-----------------------------------------------------------------------------
+from __future__ import absolute_import, division, print_function, unicode_literals
+
+import pytest ; pytest
+
+#-----------------------------------------------------------------------------
+# Imports
+#-----------------------------------------------------------------------------
+
+# Standard library imports
 import argparse
 import contextlib
 import re
 import socket
 import subprocess
 import sys
+from time import sleep
 
-import pytest
+# External imports
 import requests
 import six
 
+# Bokeh imports
 import bokeh.command.subcommands.serve as scserve
 
 from bokeh.resources import DEFAULT_SERVER_PORT
 
+#-----------------------------------------------------------------------------
+# Setup
+#-----------------------------------------------------------------------------
 
+#-----------------------------------------------------------------------------
+# General API
+#-----------------------------------------------------------------------------
+
+#-----------------------------------------------------------------------------
+# Dev API
+#-----------------------------------------------------------------------------
 
 def test_create():
     import argparse
@@ -166,11 +196,34 @@ def test_args():
         ('--num-procs', dict(
              metavar='N',
              action='store',
-             help="Number of worker processes for an app. Default to one. Using "
-                  "0 will autodetect number of cores",
+             help="Number of worker processes for an app. Using "
+                  "0 will autodetect number of cores (defaults to 1)",
              default=1,
              type=int,
          )),
+
+         ('--websocket-max-message-size', dict(
+            metavar='BYTES',
+            action='store',
+            help="Set the Tornado websocket_max_message_size value (defaults "
+                 "to 20MB) NOTE: This setting has effect ONLY for Tornado>=4.5",
+            default=20*1024*1024,
+            type=int,
+        )),
+
+        ('--dev', dict(
+            metavar ='FILES-TO-WATCH',
+            action  ='store',
+            default = None,
+            type    = str,
+            nargs   = '*',
+            help    =   "Enable live reloading during app development."
+                        "By default it watches all *.py *.html *.css *.yaml files"
+                        "in the app directory tree. Additional files can be passed"
+                        "as arguments."
+                        "NOTE: This setting only works with a single app."
+                        "It also restricts the number of processes to 1.",
+        )),
     )
 
 
@@ -207,7 +260,7 @@ def check_error(args):
     return out
 
 def test_host_not_available():
-    host = "8.8.8.8"
+    host = str("8.8.8.8") # str cast is for Python 2.7 testing
     out = check_error(["--address", host])
     expected = "Cannot start Bokeh server, address %r not available" % host
     assert expected in out
@@ -225,17 +278,37 @@ def test_port_not_available():
 
 @pytest.mark.skipif(six.PY2, reason="Travis bug causes bad file descriptor")
 def test_actual_port_printed_out():
+    from fcntl import fcntl, F_GETFL, F_SETFL
+    from os import O_NONBLOCK, read
+    pat = re.compile(r'Bokeh app running at: http://localhost:(\d+)')
+    m = None
     with run_bokeh_serve(["--port", "0"]) as p:
-        pat = re.compile(r'Bokeh app running at: http://localhost:(\d+)')
-        while True:
-            line = p.stdout.readline()
-            print("child stdout>", line)
-            m = pat.search(line.decode())
-            if m is not None:
-                break
-        else:
+        flags = fcntl(p.stdout, F_GETFL)
+        fcntl(p.stdout, F_SETFL, flags | O_NONBLOCK)
+        sleep(2)
+        o = read(p.stdout.fileno(), 100*1024)
+        m = pat.search(o.decode())
+        if m is None:
             pytest.fail("no matching log line in process output")
         port = int(m.group(1))
         assert port > 0
         r = requests.get("http://localhost:%d/" % (port,))
         assert r.status_code == 200
+
+@pytest.mark.skipif(six.PY2, reason="Travis bug causes bad file descriptor")
+def test_websocket_max_message_size_printed_out():
+    pat = re.compile(r'Torndado websocket_max_message_size set to 12345')
+    with run_bokeh_serve(["--websocket-max-message-size", "12345"]) as p:
+        sleep(2)
+    o, e = p.communicate()
+    m = pat.search(o.decode())
+    if m is None:
+        pytest.fail("no matching log line in process output")
+
+#-----------------------------------------------------------------------------
+# Private API
+#-----------------------------------------------------------------------------
+
+#-----------------------------------------------------------------------------
+# Code
+#-----------------------------------------------------------------------------
