@@ -101,7 +101,7 @@ class Document(object):
         self._all_models_by_name = MultiValuedDict()
         self._all_former_model_ids = set()
         self._callbacks = {}
-        self._session_destroyed_callbacks = {}
+        self._session_destroyed_callbacks = set()
         self._session_callbacks = set()
         self._session_context = None
         self._modules = []
@@ -132,6 +132,17 @@ class Document(object):
         '''
         return list(self._session_callbacks)
 
+    @property
+    def session_destroyed_callbacks(self):
+        ''' A list of all the on_session_destroyed callbacks on this document.
+
+        '''
+        return self._session_destroyed_callbacks
+
+    @session_destroyed_callbacks.setter
+    def session_destroyed_callbacks(self, callbacks):
+        self._session_destroyed_callbacks = callbacks
+
     @property
     def session_context(self):
         ''' The ``SessionContext`` for this document.
@@ -355,8 +366,8 @@ class Document(object):
 
         # Use our existing model instances whenever we have them
         for obj in references.values():
-            if obj._id in self._all_models:
-                references[obj._id] = self._all_models[obj._id]
+            if obj.id in self._all_models:
+                references[obj.id] = self._all_models[obj.id]
 
         # The model being changed isn't always in references so add it in
         for event_json in events_json:
@@ -664,7 +675,7 @@ class Document(object):
         '''
         for callback in callbacks:
             _check_callback(callback, ('session_context',))
-            self._session_destroyed_callbacks[callback] = callback
+            self._session_destroyed_callbacks.add(callback)
 
     def remove_next_tick_callback(self, callback_obj):
         ''' Remove a callback added earlier with ``add_next_tick_callback``.
@@ -847,7 +858,7 @@ class Document(object):
         '''
         root_ids = []
         for r in self._roots:
-            root_ids.append(r._id)
+            root_ids.append(r.id)
 
         root_references = self._all_models.values()
 
@@ -1021,11 +1032,11 @@ class Document(object):
         recomputed = {}
         recomputed_by_name = MultiValuedDict()
         for m in new_all_models_set:
-            recomputed[m._id] = m
+            recomputed[m.id] = m
             if m.name is not None:
                 recomputed_by_name.add_value(m.name, m)
         for d in to_detach:
-            self._all_former_model_ids.add(d._id)
+            self._all_former_model_ids.add(d.id)
             d._detach_document()
         for a in to_attach:
             a._attach_document(self)
