@@ -1,5 +1,5 @@
 #-----------------------------------------------------------------------------
-# Copyright (c) 2012 - 2017, Anaconda, Inc. All rights reserved.
+# Copyright (c) 2012 - 2018, Anaconda, Inc. All rights reserved.
 #
 # Powered by the Bokeh Development Team.
 #
@@ -39,6 +39,12 @@ from .util import RenderItem
 # Globals and constants
 #-----------------------------------------------------------------------------
 
+__all__ = (
+    'server_document',
+    'server_session',
+    'server_html_page_for_session',
+)
+
 #-----------------------------------------------------------------------------
 # General API
 #-----------------------------------------------------------------------------
@@ -171,7 +177,7 @@ def server_session(model=None, session_id=None, url="default", relative_urls=Fal
     app_path = _get_app_path(url)
 
     elementid = make_id()
-    modelid = "" if model is None else model._id
+    modelid = "" if model is None else model.id
     src_path = _src_path(url, elementid)
 
     src_path += _process_app_path(app_path)
