@@ -1,5 +1,5 @@
 #-----------------------------------------------------------------------------
-# Copyright (c) 2012 - 2017, Anaconda, Inc. All rights reserved.
+# Copyright (c) 2012 - 2018, Anaconda, Inc. All rights reserved.
 #
 # Powered by the Bokeh Development Team.
 #
@@ -58,6 +58,11 @@ from ..resources import Resources
 # Globals and constants
 #-----------------------------------------------------------------------------
 
+__all__ = (
+    'curstate',
+    'State',
+)
+
 #-----------------------------------------------------------------------------
 # General API
 #-----------------------------------------------------------------------------
@@ -150,7 +155,7 @@ class State(object):
             root_dir (str, optional) : root dir to use for absolute resources
                 (default: None)
 
-                This value is ignored for other resource types, e.g. ``INLINE`` or``CDN``.
+                This value is ignored for other resource types, e.g. ``INLINE`` or ``CDN``.
 
         .. warning::
             The specified output file will be overwritten on every save, e.g.,
