@@ -1,17 +1,55 @@
-from __future__ import absolute_import
+#-----------------------------------------------------------------------------
+# Copyright (c) 2012 - 2018, Anaconda, Inc. All rights reserved.
+#
+# Powered by the Bokeh Development Team.
+#
+# The full license is in the file LICENSE.txt, distributed with this software.
+#-----------------------------------------------------------------------------
 
+#-----------------------------------------------------------------------------
+# Boilerplate
+#-----------------------------------------------------------------------------
+from __future__ import absolute_import, division, print_function, unicode_literals
+
+import logging
+log = logging.getLogger(__name__)
+
+#-----------------------------------------------------------------------------
+# Imports
+#-----------------------------------------------------------------------------
+
+# Standard library imports
 import inspect
 from textwrap import dedent
 from types import FunctionType
 
+# External imports
+
+# Bokeh imports
 from ..core.properties import Bool, Dict, Either, Int, Seq, String, AnyRef
 from ..model import Model
 from ..util.dependencies import import_required
 from ..util.compiler import nodejs_compile, CompilationError
 
+#-----------------------------------------------------------------------------
+# Globals and constants
+#-----------------------------------------------------------------------------
+
+__all__ = (
+    'BooleanFilter',
+    'CustomJSFilter',
+    'Filter',
+    'GroupFilter',
+    'IndexFilter',
+)
+
+#-----------------------------------------------------------------------------
+# General API
+#-----------------------------------------------------------------------------
+
 class Filter(Model):
     ''' A Filter model represents a filtering operation that returns a row-wise subset of
-    data when applied to a ColumnDataSource.
+    data when applied to a ``ColumnDataSource``.
     '''
 
     filter = Either(Seq(Int), Seq(Bool), help="""
@@ -25,7 +63,7 @@ class Filter(Model):
         super(Filter, self).__init__(**kw)
 
 class IndexFilter(Filter):
-    ''' An IndexFilter filters data by returning the subset of data at a given set of indices.
+    ''' An ``IndexFilter`` filters data by returning the subset of data at a given set of indices.
     '''
 
     indices = Seq(Int, help="""
@@ -39,7 +77,7 @@ class IndexFilter(Filter):
         super(IndexFilter, self).__init__(**kw)
 
 class BooleanFilter(Filter):
-    ''' A BooleanFilter filters data by returning the subset of data corresponding to indices
+    ''' A ``BooleanFilter`` filters data by returning the subset of data corresponding to indices
     where the values of the booleans array is True.
     '''
 
@@ -54,7 +92,7 @@ class BooleanFilter(Filter):
         super(BooleanFilter, self).__init__(**kw)
 
 class GroupFilter(Filter):
-    ''' A GroupFilter represents the rows of a ColumnDataSource where the values of the categorical
+    ''' A ``GroupFilter`` represents the rows of a ``ColumnDataSource`` where the values of the categorical
     column column_name match the group variable.
     '''
 
@@ -86,11 +124,11 @@ class CustomJSFilter(Filter):
 
     @classmethod
     def from_py_func(cls, func):
-        ''' Create a CustomJSFilter instance from a Python function. The
-        fucntion is translated to JavaScript using PScript.
+        ''' Create a ``CustomJSFilter`` instance from a Python function. The
+        function is translated to JavaScript using PScript.
 
         The ``func`` function namespace will contain the variable ``source``
-        at render time. This will be the data source associated with the CDSView
+        at render time. This will be the data source associated with the ``CDSView``
         that this filter is added to.
         '''
         if not isinstance(func, FunctionType):
@@ -112,7 +150,7 @@ class CustomJSFilter(Filter):
             raise ValueError("Function may only contain keyword arguments.")
 
         # should the following be all of the values need to be Models?
-        if default_values and not any([isinstance(value, Model) for value in default_values]):
+        if default_values and not any(isinstance(value, Model) for value in default_values):
             raise ValueError("Default value must be a plot object.")
 
         func_kwargs = dict(zip(default_names, default_values))
@@ -122,13 +160,13 @@ class CustomJSFilter(Filter):
 
     @classmethod
     def from_coffeescript(cls, code, args={}):
-        ''' Create a CustomJSFilter instance from CoffeeScript snippets.
+        ''' Create a ``CustomJSFilter`` instance from CoffeeScript snippets.
         The function bodies are translated to JavaScript functions using node
         and therefore require return statements.
 
         The ``code`` function namespace will contain the variable ``source``
-        at render time. This will be the data source associated with the CDSView
-        that this filter is added to.
+        at render time. This will be the data source associated with the
+        ``CDSView`` that this filter is added to.
         '''
 
         compiled = nodejs_compile(code, lang="coffeescript", file="???")
@@ -147,7 +185,7 @@ class CustomJSFilter(Filter):
     A snippet of JavaScript code to filter data contained in a columnar data source.
     The code is made into the body of a function, and all of of the named objects in
     ``args`` are available as parameters that the code can use. The variable
-    ``source`` will contain the data source that is associated with the CDSView this
+    ``source`` will contain the data source that is associated with the ``CDSView`` this
     filter is added to.
 
     The code should either return the indices of the subset or an array of booleans
@@ -174,3 +212,15 @@ class CustomJSFilter(Filter):
     use_strict = Bool(default=False, help="""
     Enables or disables automatic insertion of ``"use strict";`` into ``code``.
     """)
+
+#-----------------------------------------------------------------------------
+# Dev API
+#-----------------------------------------------------------------------------
+
+#-----------------------------------------------------------------------------
+# Private API
+#-----------------------------------------------------------------------------
+
+#-----------------------------------------------------------------------------
+# Code
+#-----------------------------------------------------------------------------
