@@ -1,9 +1,32 @@
+#-----------------------------------------------------------------------------
+# Copyright (c) 2012 - 2018, Anaconda, Inc. All rights reserved.
+#
+# Powered by the Bokeh Development Team.
+#
+# The full license is in the file LICENSE.txt, distributed with this software.
+#-----------------------------------------------------------------------------
 ''' Models for computing good tick locations on different kinds
 of plots.
 
 '''
-from __future__ import absolute_import
 
+#-----------------------------------------------------------------------------
+# Boilerplate
+#-----------------------------------------------------------------------------
+from __future__ import absolute_import, division, print_function, unicode_literals
+
+import logging
+log = logging.getLogger(__name__)
+
+#-----------------------------------------------------------------------------
+# Imports
+#-----------------------------------------------------------------------------
+
+# Standard library imports
+
+# External imports
+
+# Bokeh imports
 from ..core.enums import LatLon
 from ..core.has_props import abstract
 from ..core.properties import Enum, Float, Instance, Int, Override, Seq
@@ -11,6 +34,31 @@ from ..core.validation import error
 from ..core.validation.errors import MISSING_MERCATOR_DIMENSION
 from ..model import Model
 
+#-----------------------------------------------------------------------------
+# Globals and constants
+#-----------------------------------------------------------------------------
+
+__all__ = (
+    'Ticker',
+    'ContinuousTicker',
+    'FixedTicker',
+    'AdaptiveTicker',
+    'CompositeTicker',
+    'SingleIntervalTicker',
+    'DaysTicker',
+    'MonthsTicker',
+    'YearsTicker',
+    'BasicTicker',
+    'LogTicker',
+    'MercatorTicker',
+    'CategoricalTicker',
+    'DatetimeTicker',
+)
+
+#-----------------------------------------------------------------------------
+# General API
+#-----------------------------------------------------------------------------
+
 @abstract
 class Ticker(Model):
     ''' A base class for all ticker types.
@@ -168,7 +216,7 @@ class MercatorTicker(BasicTicker):
     should be `"lat"``.
 
     In order to prevent hard to debug errors, there is no default value for
-    dimension. Using an un-configured MercatorTicker will result in a
+    dimension. Using an un-configured ``MercatorTicker`` will result in a
     validation error and a JavaScript console error.
     """)
 
@@ -231,3 +279,15 @@ class DatetimeTicker(CompositeTicker):
 
         YearsTicker(),
     ])
+
+#-----------------------------------------------------------------------------
+# Dev API
+#-----------------------------------------------------------------------------
+
+#-----------------------------------------------------------------------------
+# Private API
+#-----------------------------------------------------------------------------
+
+#-----------------------------------------------------------------------------
+# Code
+#-----------------------------------------------------------------------------
