@@ -1,8 +1,31 @@
+#-----------------------------------------------------------------------------
+# Copyright (c) 2012 - 2018, Anaconda, Inc. All rights reserved.
+#
+# Powered by the Bokeh Development Team.
+#
+# The full license is in the file LICENSE.txt, distributed with this software.
+#-----------------------------------------------------------------------------
 ''' Various kinds of data table (data grid) widgets.
 
 '''
-from __future__ import absolute_import
 
+#-----------------------------------------------------------------------------
+# Boilerplate
+#-----------------------------------------------------------------------------
+from __future__ import absolute_import, division, print_function, unicode_literals
+
+import logging
+log = logging.getLogger(__name__)
+
+#-----------------------------------------------------------------------------
+# Imports
+#-----------------------------------------------------------------------------
+
+# Standard library imports
+
+# External imports
+
+# Bokeh imports
 from ...core.enums import DateFormat, FontStyle, NumeralLanguage, TextAlign, RoundingFunction
 from ...core.has_props import abstract
 from ...core.properties import Bool, Color, Either, Enum, Float, Instance, Int, List, Override, String
@@ -12,6 +35,36 @@ from ..sources import DataSource, CDSView
 
 from .widget import Widget
 
+#-----------------------------------------------------------------------------
+# Globals and constants
+#-----------------------------------------------------------------------------
+
+__all__ = (
+    'BooleanFormatter',
+    'CellFormatter',
+    'CellEditor',
+    'CheckboxEditor',
+    'DataTable',
+    'DateEditor',
+    'DateFormatter',
+    'HTMLTemplateFormatter',
+    'IntEditor',
+    'NumberEditor',
+    'NumberFormatter',
+    'PercentEditor',
+    'SelectEditor',
+    'StringEditor',
+    'StringFormatter',
+    'TableColumn',
+    'TextEditor',
+    'TimeEditor',
+    'TableWidget',
+)
+
+#-----------------------------------------------------------------------------
+# Dev API
+#-----------------------------------------------------------------------------
+
 @abstract
 class CellFormatter(Model):
     ''' Abstract base class for data table's cell formatters.
@@ -24,6 +77,10 @@ class CellEditor(Model):
 
     '''
 
+#-----------------------------------------------------------------------------
+# General API
+#-----------------------------------------------------------------------------
+
 class StringFormatter(CellFormatter):
     ''' Basic string cell formatter.
 
@@ -527,7 +584,7 @@ class DataTable(TableWidget):
     """)
 
     reorderable = Bool(True, help="""
-    Allows the reordering of a tables's columns. To reorder a column,
+    Allows the reordering of a table's columns. To reorder a column,
     click and drag a table's header to the desired location in the table.
     The columns on either side will remain in their previous order.
     """)
@@ -576,3 +633,15 @@ class DataTable(TableWidget):
     """)
 
     height = Override(default=400)
+
+    row_height = Int(25, help="""
+    The height of each row in pixels.
+    """)
+
+#-----------------------------------------------------------------------------
+# Private API
+#-----------------------------------------------------------------------------
+
+#-----------------------------------------------------------------------------
+# Code
+#-----------------------------------------------------------------------------
