@@ -1,12 +1,50 @@
+#-----------------------------------------------------------------------------
+# Copyright (c) 2012 - 2018, Anaconda, Inc. All rights reserved.
+#
+# Powered by the Bokeh Development Team.
+#
+# The full license is in the file LICENSE.txt, distributed with this software.
+#-----------------------------------------------------------------------------
 ''' Provide classes to represent callback code that can be associate with
 Bokeh Documents and Sessions.
 
 '''
-from __future__ import absolute_import
 
+#-----------------------------------------------------------------------------
+# Boilerplate
+#-----------------------------------------------------------------------------
+from __future__ import absolute_import, division, print_function, unicode_literals
+
+import logging
+log = logging.getLogger(__name__)
+
+#-----------------------------------------------------------------------------
+# Imports
+#-----------------------------------------------------------------------------
+
+# Standard library imports
+
+# External imports
+
+# Bokeh imports
 from ..util.serialization import make_id
 from ..util.tornado import _CallbackGroup
 
+#-----------------------------------------------------------------------------
+# Globals and constants
+#-----------------------------------------------------------------------------
+
+__all__ = (
+    'NextTickCallback',
+    'PeriodicCallback',
+    'SessionCallback',
+    'TimeoutCallback',
+)
+
+#-----------------------------------------------------------------------------
+# Dev API
+#-----------------------------------------------------------------------------
+
 class SessionCallback(object):
     ''' A base class for callback objects associated with Bokeh Documents
     and Sessions.
@@ -45,6 +83,10 @@ class SessionCallback(object):
         ''' Dev API used to wrap the callback with decorators. '''
         raise NotImplementedError("_copy_with_changed_callback")
 
+#-----------------------------------------------------------------------------
+# General API
+#-----------------------------------------------------------------------------
+
 class NextTickCallback(SessionCallback):
     ''' Represent a callback to execute on the next ``IOLoop`` "tick".
 
@@ -131,6 +173,10 @@ class TimeoutCallback(SessionCallback):
         ''' Dev API used to wrap the callback with decorators. '''
         return TimeoutCallback(self._document, new_callback, self._timeout, self._id)
 
+#-----------------------------------------------------------------------------
+# Private API
+#-----------------------------------------------------------------------------
+
 class _DocumentCallbackGroup(object):
     '''
 
@@ -185,3 +231,7 @@ class _DocumentCallbackGroup(object):
                 self._group.remove_next_tick_callback(callback_obj.id)
         except ValueError:
             pass
+
+#-----------------------------------------------------------------------------
+# Code
+#-----------------------------------------------------------------------------
