@@ -1,3 +1,10 @@
+#-----------------------------------------------------------------------------
+# Copyright (c) 2012 - 2018, Anaconda, Inc. All rights reserved.
+#
+# Powered by the Bokeh Development Team.
+#
+# The full license is in the file LICENSE.txt, distributed with this software.
+#-----------------------------------------------------------------------------
 ''' Provide basic Bokeh server objects that use a Tornado ``HTTPServer`` and
 ``BokeTornado`` Tornado Application to service Bokeh Server Applications.
 There are two public classes in this module:
@@ -13,18 +20,30 @@ There are two public classes in this module:
     automatically create and coordinate the lower level Tornado components.
 
 '''
-from __future__ import absolute_import, print_function
 
-import atexit
+#-----------------------------------------------------------------------------
+# Boilerplate
+#-----------------------------------------------------------------------------
+from __future__ import absolute_import, division, print_function, unicode_literals
+
 import logging
 log = logging.getLogger(__name__)
+
+#-----------------------------------------------------------------------------
+# Imports
+#-----------------------------------------------------------------------------
+
+# Standard library imports
+import atexit
 import signal
 import sys
 
+# External imports
 import tornado
 from tornado.httpserver import HTTPServer
 from tornado.ioloop import IOLoop
 
+# Bokeh imports
 from .. import __version__
 from ..application import Application
 from ..core.properties import Bool, Int, List, String
@@ -34,56 +53,18 @@ from ..util.options import Options
 from .util import bind_sockets, create_hosts_whitelist
 from .tornado import BokehTornado, DEFAULT_WEBSOCKET_MAX_MESSAGE_SIZE_BYTES
 
-# This class itself is intentionally undocumented (it is used to generate
-# documentation elsewhere)
-class _ServerOpts(Options):
+#-----------------------------------------------------------------------------
+# Globals and constants
+#-----------------------------------------------------------------------------
 
-    num_procs = Int(default=1, help="""
-    The number of worker processes to start for the HTTP server. If an explicit
-    ``io_loop`` is also configured, then ``num_procs=1`` is the only compatible
-    value. Use ``BaseServer`` to coordinate an explicit ``IOLoop`` with a
-    multi-process HTTP server.
-
-    A value of 0 will auto detect number of cores.
-
-    Note that due to limitations inherent in Tornado, Windows does not support
-    ``num_procs`` values greater than one! In this case consider running
-    multiple Bokeh server instances behind a load balancer.
-    """)
-
-    address = String(default=None, help="""
-    The address the server should listen on for HTTP requests.
-    """)
-
-    port = Int(default=DEFAULT_SERVER_PORT, help="""
-    The port number the server should listen on for HTTP requests.
-    """)
-
-    prefix = String(default="", help="""
-    A URL prefix to use for all Bokeh server paths.
-    """)
-
-    allow_websocket_origin = List(String, default=None, help="""
-    A list of hosts that can connect to the websocket.
-
-    This is typically required when embedding a Bokeh server app in an external
-    web site using :func:`~bokeh.embed.server_document` or similar.
-
-    If None, "localhost" is used.
-    """)
-
-    use_xheaders = Bool(default=False, help="""
-    Whether to have the Bokeh server override the remote IP and URI scheme
-    and protocol for all requests with ``X-Real-Ip``, ``X-Forwarded-For``,
-    ``X-Scheme``, ``X-Forwarded-Proto`` headers (if they are provided).
-    """)
-
-    websocket_max_message_size = Int(default=DEFAULT_WEBSOCKET_MAX_MESSAGE_SIZE_BYTES, help="""
-    Set the Tornado ``websocket_max_message_size`` value.
-
-    NOTE: This setting has effect ONLY for Tornado>=4.5
-    """)
+__all__ = (
+    'BaseServer',
+    'Server',
+)
 
+#-----------------------------------------------------------------------------
+# Dev API
+#-----------------------------------------------------------------------------
 
 class BaseServer(object):
     ''' Explicitly coordinate the level Tornado components required to run a
@@ -295,6 +276,10 @@ class BaseServer(object):
         # Tell self._loop.start() to return.
         self._loop.add_callback_from_signal(self._loop.stop)
 
+#-----------------------------------------------------------------------------
+# General API
+#-----------------------------------------------------------------------------
+
 class Server(BaseServer):
     ''' A high level convenience class to run a Bokeh server.
 
@@ -446,3 +431,61 @@ class Server(BaseServer):
 
         '''
         return self._address
+
+#-----------------------------------------------------------------------------
+# Private API
+#-----------------------------------------------------------------------------
+
+# This class itself is intentionally undocumented (it is used to generate
+# documentation elsewhere)
+class _ServerOpts(Options):
+
+    num_procs = Int(default=1, help="""
+    The number of worker processes to start for the HTTP server. If an explicit
+    ``io_loop`` is also configured, then ``num_procs=1`` is the only compatible
+    value. Use ``BaseServer`` to coordinate an explicit ``IOLoop`` with a
+    multi-process HTTP server.
+
+    A value of 0 will auto detect number of cores.
+
+    Note that due to limitations inherent in Tornado, Windows does not support
+    ``num_procs`` values greater than one! In this case consider running
+    multiple Bokeh server instances behind a load balancer.
+    """)
+
+    address = String(default=None, help="""
+    The address the server should listen on for HTTP requests.
+    """)
+
+    port = Int(default=DEFAULT_SERVER_PORT, help="""
+    The port number the server should listen on for HTTP requests.
+    """)
+
+    prefix = String(default="", help="""
+    A URL prefix to use for all Bokeh server paths.
+    """)
+
+    allow_websocket_origin = List(String, default=None, help="""
+    A list of hosts that can connect to the websocket.
+
+    This is typically required when embedding a Bokeh server app in an external
+    web site using :func:`~bokeh.embed.server_document` or similar.
+
+    If None, "localhost" is used.
+    """)
+
+    use_xheaders = Bool(default=False, help="""
+    Whether to have the Bokeh server override the remote IP and URI scheme
+    and protocol for all requests with ``X-Real-Ip``, ``X-Forwarded-For``,
+    ``X-Scheme``, ``X-Forwarded-Proto`` headers (if they are provided).
+    """)
+
+    websocket_max_message_size = Int(default=DEFAULT_WEBSOCKET_MAX_MESSAGE_SIZE_BYTES, help="""
+    Set the Tornado ``websocket_max_message_size`` value.
+
+    NOTE: This setting has effect ONLY for Tornado>=4.5
+    """)
+
+#-----------------------------------------------------------------------------
+# Code
+#-----------------------------------------------------------------------------
