@@ -1,18 +1,19 @@
 from __future__ import absolute_import, print_function
 
 from mock import patch
-import unittest
+import pytest
 
 import logging
 import bokeh.document as document
+import os
 from bokeh.application import Application
 from bokeh.application.handlers import FunctionHandler
 from bokeh.client import pull_session, push_session, ClientSession
 from bokeh.document import Document
 from bokeh.model import Model
 from bokeh.models import Plot
-from bokeh.server.events import ModelChangedEvent, TitleChangedEvent
 from bokeh.core.properties import Int, Instance, Dict, String, Any, DistanceSpec, AngleSpec
+from bokeh.document.events import ModelChangedEvent, TitleChangedEvent
 from tornado import gen
 from tornado.httpclient import HTTPError
 
@@ -35,7 +36,7 @@ class UnitsSpecModel(Model):
 
 logging.basicConfig(level=logging.DEBUG)
 
-class TestClientServer(unittest.TestCase):
+class TestClientServer(object):
 
     def test_minimal_connect_and_disconnect(self):
         application = Application()
@@ -61,10 +62,10 @@ class TestClientServer(unittest.TestCase):
             session._connection._socket.write_message(b"xx", binary=True)
             # connection should now close on the server side
             # and the client loop should end
-            session.loop_until_closed()
+            session.loop_until_closed(suppress_warning=True)
             assert not session.connected
             session.close()
-            session.loop_until_closed()
+            session.loop_until_closed(suppress_warning=True)
             assert not session.connected
 
     def test_connect_with_prefix(self):
@@ -78,23 +79,23 @@ class TestClientServer(unittest.TestCase):
             session.connect()
             assert session.connected
             session.close()
-            session.loop_until_closed()
+            session.loop_until_closed(suppress_warning=True)
 
             session = ClientSession(io_loop = server.io_loop,
                                     websocket_url = ws_url(server))
             session.connect()
             assert not session.connected
             session.close()
-            session.loop_until_closed()
+            session.loop_until_closed(suppress_warning=True)
 
     def check_http_gets_fail(self, server):
-        with (self.assertRaises(HTTPError)):
+        with pytest.raises(HTTPError):
             http_get(server.io_loop, url(server))
-        with (self.assertRaises(HTTPError)):
+        with pytest.raises(HTTPError):
             http_get(server.io_loop, url(server) + "autoload.js?bokeh-autoload-element=foo")
 
     def check_connect_session_fails(self, server, origin):
-        with (self.assertRaises(HTTPError)):
+        with pytest.raises(HTTPError):
             websocket_open(server.io_loop,
                            ws_url(server)+"?bokeh-protocol-version=1.0&bokeh-session-id=foo",
                            origin=origin)
@@ -127,14 +128,32 @@ class TestClientServer(unittest.TestCase):
         with ManagedServerLoop(application, allow_websocket_origin=["example.com"]) as server:
             self.check_http_ok_socket_ok(server, origin="http://example.com:80")
 
+        # allow good origin from environment variable
+        with ManagedServerLoop(application) as server:
+            os.environ["BOKEH_ALLOW_WS_ORIGIN"] = "example.com"
+            self.check_http_ok_socket_ok(server, origin="http://example.com:80")
+            del os.environ["BOKEH_ALLOW_WS_ORIGIN"]
+
         # allow good origin with port
         with ManagedServerLoop(application, allow_websocket_origin=["example.com:8080"]) as server:
             self.check_http_ok_socket_ok(server, origin="http://example.com:8080")
 
+        # allow good origin with port from environment variable
+        with ManagedServerLoop(application) as server:
+            os.environ["BOKEH_ALLOW_WS_ORIGIN"] = "example.com:8080"
+            self.check_http_ok_socket_ok(server, origin="http://example.com:8080")
+            del os.environ["BOKEH_ALLOW_WS_ORIGIN"]
+
         # allow good origin header with an implicit 80
         with ManagedServerLoop(application, allow_websocket_origin=["example.com"]) as server:
             self.check_http_ok_socket_ok(server, origin="http://example.com")
 
+        # allow good origin header with an implicit 80
+        with ManagedServerLoop(application) as server:
+            os.environ["BOKEH_ALLOW_WS_ORIGIN"] = "example.com"
+            self.check_http_ok_socket_ok(server, origin="http://example.com")
+            del os.environ["BOKEH_ALLOW_WS_ORIGIN"]
+
         # block non-Host origins by default even if no extra origins specified
         with ManagedServerLoop(application) as server:
             self.check_http_ok_socket_blocked(server, origin="http://example.com:80")
@@ -147,10 +166,22 @@ class TestClientServer(unittest.TestCase):
         with ManagedServerLoop(application, allow_websocket_origin=["example.com"]) as server:
             self.check_http_ok_socket_blocked(server, origin="http://foobar.com:80")
 
+        # block bad origin from environment variable
+        with ManagedServerLoop(application) as server:
+            os.environ["BOKEH_ALLOW_WS_ORIGIN"] = "example.com"
+            self.check_http_ok_socket_blocked(server, origin="http://foobar.com:80")
+            del os.environ["BOKEH_ALLOW_WS_ORIGIN"]
+
         # block bad origin port
         with ManagedServerLoop(application, allow_websocket_origin=["example.com:8080"]) as server:
             self.check_http_ok_socket_blocked(server, origin="http://example.com:8081")
 
+        # block bad origin port from environment variable
+        with ManagedServerLoop(application) as server:
+            os.environ["BOKEH_ALLOW_WS_ORIGIN"] = "example.com:8080"
+            self.check_http_ok_socket_blocked(server, origin="http://example.com:8081")
+            del os.environ["BOKEH_ALLOW_WS_ORIGIN"]
+
     def test_push_document(self):
         application = Application()
         with ManagedServerLoop(application) as server:
@@ -179,7 +210,7 @@ class TestClientServer(unittest.TestCase):
             assert results['bar'] == 43
 
             client_session.close()
-            client_session.loop_until_closed()
+            client_session.loop_until_closed(suppress_warning=True)
             assert not client_session.connected
 
     def test_pull_document(self):
@@ -209,7 +240,7 @@ class TestClientServer(unittest.TestCase):
             assert results['bar'] == 43
 
             client_session.close()
-            client_session.loop_until_closed()
+            client_session.loop_until_closed(suppress_warning=True)
             assert not client_session.connected
 
     def test_request_server_info(self):
@@ -230,7 +261,7 @@ class TestClientServer(unittest.TestCase):
             assert info['version_info']['server'] == __version__
 
             session.close()
-            session.loop_until_closed()
+            session.loop_until_closed(suppress_warning=True)
             assert not session.connected
 
     def test_ping(self):
@@ -245,19 +276,19 @@ class TestClientServer(unittest.TestCase):
 
             connection = next(iter(server._tornado._clients))
             expected_pong = connection._ping_count
-            server._tornado.keep_alive() # send ping
+            server._tornado._keep_alive() # send ping
             session.force_roundtrip()
 
-            self.assertEqual(expected_pong, connection._socket.latest_pong)
+            assert expected_pong == connection._socket.latest_pong
 
             # check that each ping increments by 1
-            server._tornado.keep_alive()
+            server._tornado._keep_alive()
             session.force_roundtrip()
 
-            self.assertEqual(expected_pong + 1, connection._socket.latest_pong)
+            assert (expected_pong + 1) == connection._socket.latest_pong
 
             session.close()
-            session.loop_until_closed()
+            session.loop_until_closed(suppress_warning=True)
             assert not session.connected
 
     def test_client_changes_go_to_server(self):
@@ -305,7 +336,7 @@ class TestClientServer(unittest.TestCase):
             assert len(server_session.document.roots) == 0
 
             client_session.close()
-            client_session.loop_until_closed()
+            client_session.loop_until_closed(suppress_warning=True)
             assert not client_session.connected
 
     def test_server_changes_go_to_client(self):
@@ -368,7 +399,7 @@ class TestClientServer(unittest.TestCase):
             assert len(client_session.document.roots) == 0
 
             client_session.close()
-            client_session.loop_until_closed()
+            client_session.loop_until_closed(suppress_warning=True)
             assert not client_session.connected
 
     @gen.coroutine
@@ -399,15 +430,15 @@ class TestClientServer(unittest.TestCase):
                 client_session.close()
                 raise gen.Return(5)
 
-            doc.add_timeout_callback(cb, 10)
+            cb_id = doc.add_timeout_callback(cb, 10)
 
-            client_session.loop_until_closed()
+            client_session.loop_until_closed(suppress_warning=True)
 
-            with (self.assertRaises(ValueError)) as manager:
-                doc.remove_timeout_callback(cb)
-            self.assertTrue('already removed' in repr(manager.exception))
+            with pytest.raises(ValueError) as exc:
+                doc.remove_timeout_callback(cb_id)
+            assert 'already removed' in repr(exc.value)
 
-            self.assertDictEqual(dict(a=0, b=1, c=2, d=3, e=4), result.values)
+            assert dict(a=0, b=1, c=2, d=3, e=4) == result.values
 
     def test_client_session_timeout_async_added_before_push(self):
         application = Application()
@@ -427,20 +458,20 @@ class TestClientServer(unittest.TestCase):
                 client_session.close()
                 raise gen.Return(5)
 
-            doc.add_timeout_callback(cb, 10)
+            cb_id = doc.add_timeout_callback(cb, 10)
 
             client_session = push_session(doc,
                                           session_id='test_client_session_timeout_async',
                                           url=url(server),
                                           io_loop=server.io_loop)
 
-            client_session.loop_until_closed()
+            client_session.loop_until_closed(suppress_warning=True)
 
-            with (self.assertRaises(ValueError)) as manager:
-                doc.remove_timeout_callback(cb)
-            self.assertTrue('already removed' in repr(manager.exception))
+            with pytest.raises(ValueError) as exc:
+                doc.remove_timeout_callback(cb_id)
+            assert 'already removed' in repr(exc.value)
 
-            self.assertDictEqual(dict(a=0, b=1, c=2, d=3, e=4), result.values)
+            assert dict(a=0, b=1, c=2, d=3, e=4) == result.values
 
     def test_server_session_timeout_async(self):
         application = Application()
@@ -468,15 +499,15 @@ class TestClientServer(unittest.TestCase):
                 client_session.close()
                 raise gen.Return(5)
 
-            server_session.document.add_timeout_callback(cb, 10)
+            cb_id = server_session.document.add_timeout_callback(cb, 10)
 
-            client_session.loop_until_closed()
+            client_session.loop_until_closed(suppress_warning=True)
 
-            with (self.assertRaises(ValueError)) as manager:
-                server_session.document.remove_timeout_callback(cb)
-            self.assertTrue('already removed' in repr(manager.exception))
+            with pytest.raises(ValueError) as exc:
+                server_session.document.remove_timeout_callback(cb_id)
+            assert 'already removed' in repr(exc.value)
 
-            self.assertDictEqual(dict(a=0, b=1, c=2, d=3, e=4), result.values)
+            assert dict(a=0, b=1, c=2, d=3, e=4) == result.values
 
     def test_client_session_next_tick_async(self):
         application = Application()
@@ -501,15 +532,15 @@ class TestClientServer(unittest.TestCase):
                 client_session.close()
                 raise gen.Return(5)
 
-            doc.add_next_tick_callback(cb)
+            cb_id = doc.add_next_tick_callback(cb)
 
-            client_session.loop_until_closed()
+            client_session.loop_until_closed(suppress_warning=True)
 
-            with (self.assertRaises(ValueError)) as manager:
-                doc.remove_next_tick_callback(cb)
-            self.assertTrue('already removed' in repr(manager.exception))
+            with pytest.raises(ValueError) as exc:
+                doc.remove_next_tick_callback(cb_id)
+            assert 'already removed' in repr(exc.value)
 
-            self.assertDictEqual(dict(a=0, b=1, c=2, d=3, e=4), result.values)
+            assert dict(a=0, b=1, c=2, d=3, e=4) == result.values
 
     def test_client_session_next_tick_async_added_before_push(self):
         application = Application()
@@ -529,20 +560,20 @@ class TestClientServer(unittest.TestCase):
                 client_session.close()
                 raise gen.Return(5)
 
-            doc.add_next_tick_callback(cb)
+            cb_id = doc.add_next_tick_callback(cb)
 
             client_session = push_session(doc,
                                           session_id='test_client_session_next_tick_async',
                                           url=url(server),
                                           io_loop=server.io_loop)
 
-            client_session.loop_until_closed()
+            client_session.loop_until_closed(suppress_warning=True)
 
-            with (self.assertRaises(ValueError)) as manager:
-                doc.remove_next_tick_callback(cb)
-            self.assertTrue('already removed' in repr(manager.exception))
+            with pytest.raises(ValueError) as exc:
+                doc.remove_next_tick_callback(cb_id)
+            assert 'already removed' in repr(exc.value)
 
-            self.assertDictEqual(dict(a=0, b=1, c=2, d=3, e=4), result.values)
+            assert dict(a=0, b=1, c=2, d=3, e=4) == result.values
 
     def test_server_session_next_tick_async(self):
         application = Application()
@@ -570,15 +601,15 @@ class TestClientServer(unittest.TestCase):
                 client_session.close()
                 raise gen.Return(5)
 
-            server_session.document.add_next_tick_callback(cb)
+            cb_id = server_session.document.add_next_tick_callback(cb)
 
-            client_session.loop_until_closed()
+            client_session.loop_until_closed(suppress_warning=True)
 
-            with (self.assertRaises(ValueError)) as manager:
-                server_session.document.remove_next_tick_callback(cb)
-            self.assertTrue('already removed' in repr(manager.exception))
+            with pytest.raises(ValueError) as exc:
+                server_session.document.remove_next_tick_callback(cb_id)
+            assert 'already removed' in repr(exc.value)
 
-            self.assertDictEqual(dict(a=0, b=1, c=2, d=3, e=4), result.values)
+            assert dict(a=0, b=1, c=2, d=3, e=4) == result.values
 
     def test_client_session_periodic_async(self):
         application = Application()
@@ -603,13 +634,13 @@ class TestClientServer(unittest.TestCase):
                 client_session.close()
                 raise gen.Return(5)
 
-            doc.add_periodic_callback(cb, 10)
+            cb_id = doc.add_periodic_callback(cb, 10)
 
-            client_session.loop_until_closed()
+            client_session.loop_until_closed(suppress_warning=True)
 
-            doc.remove_periodic_callback(cb)
+            doc.remove_periodic_callback(cb_id)
 
-            self.assertDictEqual(dict(a=0, b=1, c=2, d=3, e=4), result.values)
+            assert dict(a=0, b=1, c=2, d=3, e=4) == result.values
 
     def test_client_session_periodic_async_added_before_push(self):
         application = Application()
@@ -629,18 +660,18 @@ class TestClientServer(unittest.TestCase):
                 client_session.close()
                 raise gen.Return(5)
 
-            doc.add_periodic_callback(cb, 10)
+            cb_id = doc.add_periodic_callback(cb, 10)
 
             client_session = push_session(doc,
                                           session_id='test_client_session_periodic_async',
                                           url=url(server),
                                           io_loop=server.io_loop)
 
-            client_session.loop_until_closed()
+            client_session.loop_until_closed(suppress_warning=True)
 
-            doc.remove_periodic_callback(cb)
+            doc.remove_periodic_callback(cb_id)
 
-            self.assertDictEqual(dict(a=0, b=1, c=2, d=3, e=4), result.values)
+            assert dict(a=0, b=1, c=2, d=3, e=4) == result.values
 
     def test_server_session_periodic_async(self):
         application = Application()
@@ -668,13 +699,13 @@ class TestClientServer(unittest.TestCase):
                 client_session.close()
                 raise gen.Return(5)
 
-            server_session.document.add_periodic_callback(cb, 10)
+            cb_id = server_session.document.add_periodic_callback(cb, 10)
 
-            client_session.loop_until_closed()
+            client_session.loop_until_closed(suppress_warning=True)
 
-            server_session.document.remove_periodic_callback(cb)
+            server_session.document.remove_periodic_callback(cb_id)
 
-            self.assertDictEqual(dict(a=0, b=1, c=2, d=3, e=4), result.values)
+            assert dict(a=0, b=1, c=2, d=3, e=4) == result.values
 
     def test_lots_of_concurrent_messages(self):
         application = Application()
@@ -687,18 +718,18 @@ class TestClientServer(unittest.TestCase):
             doc.add_root(m3)
             def timeout1():
                 m1.bar += 1
-            doc.add_timeout_callback(timeout1, 1)
+            timeout1_cb_id = doc.add_timeout_callback(timeout1, 1)
             def timeout2():
                 m2.foo +=1
-            doc.add_timeout_callback(timeout2, 3)
+            timeout2_cb_id = doc.add_timeout_callback(timeout2, 3)
             def periodic1():
                 m1.bar += 1
-                doc.remove_timeout_callback(timeout1)
+                doc.remove_timeout_callback(timeout1_cb_id)
                 doc.add_timeout_callback(timeout1, m1.bar % 7)
             doc.add_periodic_callback(periodic1, 3)
             def periodic2():
                 m2.foo += 1
-                doc.remove_timeout_callback(timeout2)
+                doc.remove_timeout_callback(timeout2_cb_id)
                 doc.add_timeout_callback(timeout2, m2.foo % 7)
             doc.add_periodic_callback(periodic2, 1)
 
@@ -724,12 +755,12 @@ class TestClientServer(unittest.TestCase):
             def client_timeout():
                 m = session.document.roots[0]
                 m.name = m.name[::-1]
-            session.document.add_timeout_callback(client_timeout, 3)
+            cb_id = session.document.add_timeout_callback(client_timeout, 3)
 
             def client_periodic():
                 m = session.document.roots[1]
                 m.name = m.name[::-1]
-                session.document.remove_timeout_callback(client_timeout)
+                session.document.remove_timeout_callback(cb_id)
                 session.document.add_timeout_callback(client_timeout, 3)
 
             session.document.add_periodic_callback(client_periodic, 1)
@@ -752,7 +783,7 @@ class TestClientServer(unittest.TestCase):
 
             session.document.on_change(client_on_change)
 
-            session.loop_until_closed()
+            session.loop_until_closed(suppress_warning=True)
 
             assert not session.connected
 
@@ -765,8 +796,6 @@ class TestClientServer(unittest.TestCase):
             assert result['server_connection_count'] == 1
             assert result['server_close_code'] is None
 
-# This isn't in the unittest.TestCase because per-test fixtures
-# don't work there (see note at bottom of https://pytest.org/latest/unittest.html#unittest-testcase)
 def test_client_changes_do_not_boomerang(monkeypatch):
     application = Application()
     with ManagedServerLoop(application) as server:
@@ -809,12 +838,10 @@ def test_client_changes_do_not_boomerang(monkeypatch):
         assert got_angry['result'] is None
 
         client_session.close()
-        client_session.loop_until_closed()
+        client_session.loop_until_closed(suppress_warning=True)
         assert not client_session.connected
         server.unlisten() # clean up so next test can run
 
-# This isn't in the unittest.TestCase because per-test fixtures
-# don't work there (see note at bottom of https://pytest.org/latest/unittest.html#unittest-testcase)
 def test_server_changes_do_not_boomerang(monkeypatch):
     application = Application()
     with ManagedServerLoop(application) as server:
@@ -860,7 +887,7 @@ def test_server_changes_do_not_boomerang(monkeypatch):
         assert got_angry['result'] is None
 
         client_session.close()
-        client_session.loop_until_closed()
+        client_session.loop_until_closed(suppress_warning=True)
         assert not client_session.connected
 
 # this test is because we do the funky serializable_value
@@ -917,7 +944,7 @@ def test_unit_spec_changes_do_not_boomerang(monkeypatch):
         change_to({ 'value' : 59, 'units' : 'screen' }, { 'value' : 30, 'units' : 'deg' })
 
         client_session.close()
-        client_session.loop_until_closed()
+        client_session.loop_until_closed(suppress_warning=True)
         assert not client_session.connected
         server.unlisten() # clean up so next test can run
 
