@@ -4,6 +4,8 @@ interfaces to classes.
 '''
 from __future__ import absolute_import
 
+from six import string_types
+
 from ..events import Event
 from ..util.future import get_param_info, format_signature, signature
 
@@ -28,7 +30,7 @@ class EventCallbackManager(object):
         self._event_callbacks = dict()
 
     def on_event(self, event, *callbacks):
-        if not isinstance(event, str) and issubclass(event, Event):
+        if not isinstance(event, string_types) and issubclass(event, Event):
             event = event.event_name
 
         for callback in callbacks:
@@ -44,15 +46,15 @@ class EventCallbackManager(object):
 
     def _trigger_event(self, event):
         for callback in self._event_callbacks.get(event.event_name,[]):
-            if event._model_id is not None and self._id == event._model_id:
+            if event._model_id is not None and self.id == event._model_id:
                 callback(event)
 
     def _update_event_callbacks(self):
         if self.document is None:
             return
 
-        if self._event_callbacks.keys():
-            self.document.event_manager.subscribed_models.add(self)
+        for key in self._event_callbacks:
+            self.document._subscribed_models[key].add(self)
 
 
 class PropertyCallbackManager(object):
@@ -115,7 +117,6 @@ class PropertyCallbackManager(object):
                 for callback in callbacks:
                     callback(attr, old, new)
         if hasattr(self, '_document') and self._document is not None:
-            self._document._notify_change(self, attr, old, new, hint, setter)
-            self._document._with_self_as_curdoc(invoke)
+            self._document._notify_change(self, attr, old, new, hint, setter, invoke)
         else:
             invoke()
